GetOrderById class

Constructors

GetOrderById({required String? sId, required String? orderDate, required String? orderId, required String? bookingId, required double? shippingFees, required String? returnReason, required String? returnRejectionReason, required String? cancellationReason, required String? paymentMode, required bool? checkPackage, required String? imageUrl, required int? paymentStatus, required int? orderStatus, required int? orderType, required List<History>? history, required User? user, required Price? price, required BillingAddress? billingAddress, required BillingAddress? shippingAddress, required List<OrderProducts>? orderProducts, required String? sTypename})
GetOrderById.fromJson(Map<String, dynamic> json)

Properties

billingAddress BillingAddress?
latefinal
bookingId String?
latefinal
cancellationReason String?
latefinal
checkPackage bool?
latefinal
hashCode int
The hash code for this object.
no setterinherited
history List<History>?
latefinal
imageUrl String?
latefinal
orderDate String?
latefinal
orderId String?
latefinal
orderProducts List<OrderProducts>?
latefinal
orderStatus int?
latefinal
orderType int?
latefinal
paymentMode String?
latefinal
paymentStatus int?
latefinal
price Price?
latefinal
returnReason String?
latefinal
returnRejectionReason String?
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingAddress BillingAddress?
latefinal
shippingFees double?
latefinal
sId String?
latefinal
sTypename String?
latefinal
user User?
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited