LoginPreferenceSetting class

Constructors

LoginPreferenceSetting({required bool? smsOtp, required bool? emailOtp, required bool? country})
LoginPreferenceSetting.fromJson(Map<String, dynamic> json)

Properties

country bool?
latefinal
emailOtp bool?
latefinal
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
smsOtp bool?
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited