CreateOrderRequest class

Constructors

CreateOrderRequest({required BillingAddress? billingAddress, required ShippingAddress? shippingAddress, required User? user, required int? orderStatus, required int? paymentStatus, required PriceDetails? price, required String? imageUrl, required List<OrderProductDetails>? orderProducts, required int? orderType})
CreateOrderRequest.fromJson(Map<String, dynamic> json)

Properties

billingAddress BillingAddress?
latefinal
hashCode int
The hash code for this object.
no setterinherited
imageUrl String?
latefinal
orderProducts List<OrderProductDetails>?
latefinal
orderStatus int?
latefinal
orderType int?
latefinal
paymentStatus int?
latefinal
price PriceDetails?
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shippingAddress ShippingAddress?
latefinal
user User?
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited